==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files_external/l10n/id.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Permintaan pengambilan token gagal. Pastikan kunci dan kerahasiaan aplikasi Anda sudah benar.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Akses pengambilan token gagal. Pastikan kunci dan kerahasiaan aplikasi Anda sudah benar.",
    "Please provide a valid app key and secret." : "Silakan berikan kunci dan kerahasiaan aplikasi yang benar.",
    "Step 1 failed. Exception: %s" : "Langkah 1 gagal. Kecuali: %s",
    "Step 2 failed. Exception: %s" : "Langkah 2 gagal. Kecuali: %s",
    "External storage" : "Penyimpanan eksternal",
    "Dropbox App Configuration" : "Konfigurasi Aplikasi Dropbox",
    "Google Drive App Configuration" : "Konfigurasi Aplikasi Google Drive",
    "Personal" : "Pribadi",
    "System" : "Sistem",
    "Grant access" : "Berikan hak akses",
    "Error configuring OAuth1" : "Kesalahan mengkonfigurasi OAuth1",
    "Error configuring OAuth2" : "Kesalahan mengkonfigurasi OAuth2",
    "Generate keys" : "Hasilkan kunci",
    "Error generating key pair" : "Kesalahan saat menghasilkan pasangan kunci",
    "All users. Type to select user or group." : "Semua pengguna. Ketik untuk memilih pengguna atau grup.",
    "(group)" : "(grup)",
    "Compatibility with Mac NFD encoding (slow)" : "Kecocokan dengan pengkodean Mac NFD (lambat)",
    "Admin defined" : "Terdefinisi Admin",
    "Saved" : "Disimpan",
    "Saving..." : "Menyimpan...",
    "Save" : "Simpan",
    "Empty response from the server" : "Tidak ada respon dari server",
    "Couldn't access. Please logout and login to activate this mount point" : "Tidak dapat mengakses. Log keluar dan log masuk untuk mengaktifkan mount point ini",
    "Couldn't get the list of external mount points: {type}" : "Tidak bisa mendapatkan informasi dari mount point eksternal: {type}",
    "There was an error with message: " : "Terjadi kesalahan dengan pesan:",
    "External mount error" : "Kesalahan mount eksternal",
    "external-storage" : "penyimpanan-eksternal",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Tidak bisa mendapatkan daftar jaringan drive mount point Windows: Tidak ada respon dari server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Beberapa mount point eksternal tidak terhubung. Klik barisan merah untuk informasi selanjutnya",
    "Please enter the credentials for the {mount} mount" : "Masukkan kredensial untuk mount {mount}",
    "Username" : "Nama Pengguna",
    "Password" : "Sandi",
    "Credentials saved" : "Kredensial tersimpan",
    "Credentials saving failed" : "Penyimpanan kredensial gagal",
    "Credentials required" : "Kredensial dibutuhkan",
    "Storage with id \"%i\" not found" : "Penyimpanan dengan id \"%i\" tidak ditemukan",
    "Invalid backend or authentication mechanism class" : "Beckend atau kelas mekanisme otentikasi salah.",
    "Invalid mount point" : "Mount point salah",
    "Objectstore forbidden" : "Objectstore terlarang",
    "Invalid storage backend \"%s\"" : "Backend penyimpanan \"%s\" salah",
    "Not permitted to use backend \"%s\"" : "Tidak diizinkan menggunakan backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Tidak diizinkan menggunakan mekanisme otentikasi \"%s\"",
    "Unsatisfied backend parameters" : "Parameter backend tidak lengkap",
    "Unsatisfied authentication mechanism parameters" : "Parameter mekanisme otentikasi tidak lengkap",
    "Insufficient data: %s" : "Data tidak cukup: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Penyimpanan dengan id \"%i\" tidak bisa diubah pengguna",
    "Access key" : "Kunci akses",
    "Secret key" : "Kunci rahasia",
    "Builtin" : "Internal",
    "None" : "Tidak ada",
    "OAuth1" : "OAuth1",
    "App key" : "Kunci Apl",
    "App secret" : "Rahasia Apl",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID Klien",
    "Client secret" : "Rahasia klien",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nama tenant",
    "Identity endpoint URL" : "Identitas URL akhir",
    "Rackspace" : "Rackspace",
    "API key" : "Kunci API",
    "Log-in credentials, save in database" : "Kredensial masuk, simpan di basis data",
    "Username and password" : "Nama pengguna dan sandi",
    "Log-in credentials, save in session" : "Kredensial masuk, simpan dalam sesi",
    "User entered, store in database" : "Dimasukkan pengguna, masukkan dalam basis data",
    "RSA public key" : "Kunci publik RSA",
    "Public key" : "Kunci Public",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Keranjang",
    "Hostname" : "Nama Host",
    "Port" : "Port",
    "Region" : "Daerah",
    "Enable SSL" : "Aktifkan SSL",
    "Enable Path Style" : "Aktifkan Gaya Path",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subfolder remote",
    "Secure https://" : "Secure https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "lokasi",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP dengan kunci rahasia masuk",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Bagikan",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS menggunakan OC login",
    "Username as share" : "Nama pengguna berbagi",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nama layanan",
    "Request timeout (seconds)" : "Minta waktu habis (detik)",
    "No external storage configured" : "Penyimpanan eksternal tidak dikonfigurasi",
    "You can add external storages in the personal settings" : "Anda dapat menambahkan penyimpanan eksternal di pengaturan pribadi",
    "Name" : "Nama",
    "Storage type" : "Tipe penyimpanan",
    "Scope" : "Skop",
    "Enable encryption" : "Aktifkan enkripsi",
    "Enable previews" : "Aktifkan pratinjau",
    "Enable sharing" : "Aktifkan pembagian",
    "Check for changes" : "Periksa perubahan",
    "Never" : "Jangan pernah",
    "Once every direct access" : "Setiap kali akses langsung",
    "Folder name" : "Nama folder",
    "Authentication" : "Otentikasi",
    "Configuration" : "Konfigurasi",
    "Available for" : "Tersedia untuk",
    "Add storage" : "Tambahkan penyimpanan",
    "Advanced settings" : "Pengaturan Lanjutan",
    "Delete" : "Hapus",
    "Allow users to mount external storage" : "Izinkan pengguna untuk mengaitkan penyimpanan eksternal",
    "Allow users to mount the following external storage" : "Izinkan pengguna untuk mengaitkan penyimpanan eksternal berikut",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Tidak bisa mendapatkan informasi dari server ownCloud: {code} {type}",
    "Access granted" : "Akses diberikan",
    "Global Credentials" : "Kredensial Global",
    "ownCloud" : "ownCloud",
    "<b>Note:</b> " : "<b>Catatan:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Catatan:</b> Dukungan cURL di PHP tidak diaktifkan atau belum diinstal. Mengaitkan %s tidak dimungkinkan. Silakan minta administrator sistem Anda untuk menginstalnya.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Catatan:</b> Dukungan FTP di PHP tidak diaktifkan atau belum diinstal. Mengaitkan %s tidak dimungkinkan. Silakan minta administrator sistem Anda untuk menginstalnya.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Catatan:</b> \"%s\" belum diinstal. Mengaitkan %s tidak dimungkinkan. Silakan minta administrator sistem Anda untuk menginstalnya.",
    "External Storage" : "Penyimpanan Eksternal"
},
"nplurals=1; plural=0;");

==> nextcloud-11.0.8.tar.bz2: nextcloud/apps/files_external/l10n/id.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Penyimpanan Eksternal",
    "Personal" : "Pribadi",
    "System" : "Sistem",
    "Grant access" : "Berikan hak akses",
    "Error configuring OAuth1" : "Kesalahan mengkonfigurasi OAuth1",
    "Please provide a valid app key and secret." : "Silakan berikan kunci dan kerahasiaan aplikasi yang benar.",
    "Error configuring OAuth2" : "Kesalahan mengkonfigurasi OAuth2",
    "Generate keys" : "Hasilkan kunci",
    "Error generating key pair" : "Kesalahan saat menghasilkan pasangan kunci",
    "All users. Type to select user or group." : "Semua pengguna. Ketik untuk memilih pengguna atau grup.",
    "(group)" : "(grup)",
    "Compatibility with Mac NFD encoding (slow)" : "Kecocokan dengan pengkodean Mac NFD (lambat)",
    "Admin defined" : "Terdefinisi Admin",
    "Saved" : "Disimpan",
    "Saving..." : "Menyimpan...",
    "Save" : "Simpan",
    "Empty response from the server" : "Tidak ada respon dari server",
    "Couldn't get the information from the remote server: {code} {type}" : "Tidak dapat mengambil informasi dari server remote: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Tidak bisa mendapatkan informasi dari mount point eksternal: {type}",
    "There was an error with message: " : "Terjadi kesalahan dengan pesan:",
    "External mount error" : "Kesalahan mount eksternal",
    "external-storage" : "penyimpanan-eksternal",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Beberapa mount point eksternal tidak terhubung. Klik barisan merah untuk informasi selanjutnya",
    "Please enter the credentials for the {mount} mount" : "Masukkan kredensial untuk mount {mount}",
    "Username" : "Nama Pengguna",
    "Password" : "Kata sandi",
    "Credentials saved" : "Kredensial tersimpan",
    "Credentials saving failed" : "Penyimpanan kredensial gagal",
    "Credentials required" : "Kredensial dibutuhkan",
    "Invalid backend or authentication mechanism class" : "Beckend atau kelas mekanisme otentikasi salah.",
    "Invalid mount point" : "Mount point salah",
    "Objectstore forbidden" : "Objectstore terlarang",
    "Invalid storage backend \"%s\"" : "Backend penyimpanan \"%s\" salah",
    "Not permitted to use backend \"%s\"" : "Tidak diizinkan menggunakan backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Tidak diizinkan menggunakan mekanisme otentikasi \"%s\"",
    "Unsatisfied backend parameters" : "Parameter backend tidak lengkap",
    "Unsatisfied authentication mechanism parameters" : "Parameter mekanisme otentikasi tidak lengkap",
    "Insufficient data: %s" : "Data tidak cukup: %s",
    "%s" : "%s",
    "Access key" : "Kunci akses",
    "Secret key" : "Kunci rahasia",
    "Builtin" : "Internal",
    "None" : "Tidak ada",
    "OAuth1" : "OAuth1",
    "App key" : "Kunci Apl",
    "App secret" : "Rahasia Apl",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID Klien",
    "Client secret" : "Rahasia klien",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nama tenant",
    "Identity endpoint URL" : "Identitas URL akhir",
    "Rackspace" : "Rackspace",
    "API key" : "Kunci API",
    "Global credentials" : "Kata sandi Global",
    "Log-in credentials, save in database" : "Kredensial masuk, simpan di basis data",
    "Username and password" : "Nama pengguna dan kata sandi",
    "Log-in credentials, save in session" : "Kredensial masuk, simpan dalam sesi",
    "User entered, store in database" : "Dimasukkan pengguna, masukkan dalam basis data",
    "RSA public key" : "Kunci publik RSA",
    "Public key" : "Kunci Public",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Keranjang",
    "Hostname" : "Nama Host",
    "Port" : "Port",
    "Region" : "Daerah",
    "Enable SSL" : "Aktifkan SSL",
    "Enable Path Style" : "Aktifkan Gaya Path",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subfolder remote",
    "Secure https://" : "Secure https://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "Lokal",
    "Location" : "lokasi",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP dengan kunci rahasia masuk",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Bagikan",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS menggunakan OC login",
    "Username as share" : "Nama pengguna berbagi",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nama layanan",
    "Request timeout (seconds)" : "Minta waktu habis (detik)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Dukungan cURL di PHP tidak diaktifkan atau terpasang. Mengaitkan %s tidak memungkinkan. Harap tanyakan administrator sistem anda untuk memasangnya.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Dukungan FTP di PHP tidak diaktifkan atau terpasang. Mengaitkan %s tidak memungkinkan. Harap tanya administrator sistem anda untuk memasangnya.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" tidak terpasang. Mengaitkan %s tidak memungkinkan. Harap tanya administrator sistem anda untuk memasangnya.",
    "No external storage configured" : "Penyimpanan eksternal tidak dikonfigurasi",
    "You can add external storages in the personal settings" : "Anda dapat menambahkan penyimpanan eksternal di pengaturan pribadi",
    "Name" : "Nama",
    "Storage type" : "Tipe penyimpanan",
    "Scope" : "Skop",
    "Enable encryption" : "Aktifkan enkripsi",
    "Enable previews" : "Aktifkan pratinjau",
    "Enable sharing" : "Aktifkan pembagian",
    "Check for changes" : "Periksa perubahan",
    "Never" : "Jangan pernah",
    "Once every direct access" : "Setiap kali akses langsung",
    "Folder name" : "Nama folder",
    "External storage" : "Penyimpanan eksternal",
    "Authentication" : "Otentikasi",
    "Configuration" : "Konfigurasi",
    "Available for" : "Tersedia untuk",
    "Add storage" : "Tambahkan penyimpanan",
    "Advanced settings" : "Pengaturan Lanjutan",
    "Delete" : "Hapus",
    "Allow users to mount external storage" : "Izinkan pengguna untuk mengaitkan penyimpanan eksternal",
    "Allow users to mount the following external storage" : "Izinkan pengguna untuk mengaitkan penyimpanan eksternal berikut",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Permintaan pengambilan token gagal. Pastikan kunci dan kerahasiaan aplikasi Anda sudah benar.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Akses pengambilan token gagal. Pastikan kunci dan kerahasiaan aplikasi Anda sudah benar.",
    "Step 1 failed. Exception: %s" : "Langkah 1 gagal. Kecuali: %s",
    "Step 2 failed. Exception: %s" : "Langkah 2 gagal. Kecuali: %s",
    "Dropbox App Configuration" : "Konfigurasi Aplikasi Dropbox",
    "Google Drive App Configuration" : "Konfigurasi Aplikasi Google Drive",
    "Storage with id \"%i\" not found" : "Penyimpanan dengan id \"%i\" tidak ditemukan",
    "Storage with id \"%i\" is not user editable" : "Penyimpanan dengan id \"%i\" tidak bisa diubah pengguna",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive"
},
"nplurals=1; plural=0;");
